(***********************************************************************)
(*                                                                     *)
(*                 MLTk, Tcl/Tk interface of OCaml                     *)
(*                                                                     *)
(*    Francois Rouaix, Francois Pessaux, Jun Furuse and Pierre Weis    *)
(*               projet Cristal, INRIA Rocquencourt                    *)
(*            Jacques Garrigue, Kyoto University RIMS                  *)
(*                                                                     *)
(*  Copyright 2002 Institut National de Recherche en Informatique et   *)
(*  en Automatique and Kyoto University.  All rights reserved.         *)
(*  This file is distributed under the terms of the GNU Library        *)
(*  General Public License, with the special exception on linking      *)
(*  described in file LICENSE found in the OCaml source tree.          *)
(*                                                                     *)
(***********************************************************************)
open Camltk

val new_vertical :
  Widget.widget -> int -> int -> Widget.widget * (int -> unit)
  (* [new_vertical parent width height]
     creates a vertical fillbox of [width] and [height].
     Returns a frame widget and a function to set the current value of
     the fillbox. The value can be
      n < 0        : the fillbox changes color (reddish)
      0 <= n <= 100: the fillbox fills up to n percent
      100 <= n     : the fillbox fills up to 95%
   *)

val new_horizontal :
  Widget.widget -> int -> int -> Widget.widget * (int -> unit)
  (* save as above, except the widget is horizontal *)
